@@ -50,6 +50,7 @@ typedef struct
     GtkListBox *results_listbox;
     GQueue *pending_results;
     GList *results;
+    guint insert_idle_id;
 } GlEventViewPrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (GlEventView, gl_event_view, GTK_TYPE_STACK)
@@ -235,6 +236,8 @@ gl_event_view_list_box_new (GlEventView *view)
                                   view, NULL);
     gtk_list_box_set_placeholder (GTK_LIST_BOX (listbox),
                                   gl_event_view_create_empty (view));
+    gtk_list_box_set_selection_mode (GTK_LIST_BOX (listbox),
+                                     GTK_SELECTION_NONE);
     g_signal_connect (listbox, "row-activated",
                       G_CALLBACK (on_listbox_row_activated), GTK_STACK (view));
 
@@ -280,6 +283,7 @@ insert_devices_idle (GlEventView *view)
                 priv->results_listbox = NULL;
                 priv->results = NULL;
 
+                priv->insert_idle_id = 0;
                 return G_SOURCE_REMOVE;
             }
         }
@@ -288,6 +292,7 @@ insert_devices_idle (GlEventView *view)
     }
     else
     {
+        priv->insert_idle_id = 0;
         return G_SOURCE_REMOVE;
     }
 }
@@ -300,7 +305,6 @@ insert_journal_query_devices (GlEventView *view,
     GlEventViewPrivate *priv;
     GList *l;
     gsize n_results;
-    guint idle_id;
 
     priv = gl_event_view_get_instance_private (view);
     priv->results = gl_journal_query (priv->journal, query);
@@ -320,8 +324,9 @@ insert_journal_query_devices (GlEventView *view,
         g_queue_push_tail (priv->pending_results, l->data);
     }
 
-    idle_id = g_idle_add ((GSourceFunc) insert_devices_idle, view);
-    g_source_set_name_by_id (idle_id, G_STRFUNC);
+    priv->insert_idle_id = g_idle_add ((GSourceFunc) insert_devices_idle,
+                                       view);
+    g_source_set_name_by_id (priv->insert_idle_id, G_STRFUNC);
 }
 
 static gboolean
@@ -363,6 +368,7 @@ insert_security_idle (GlEventView *view)
                 priv->results_listbox = NULL;
                 priv->results = NULL;
 
+                priv->insert_idle_id = 0;
                 return G_SOURCE_REMOVE;
             }
         }
@@ -371,6 +377,7 @@ insert_security_idle (GlEventView *view)
     }
     else
     {
+        priv->insert_idle_id = 0;
         return G_SOURCE_REMOVE;
     }
 }
@@ -383,7 +390,6 @@ insert_journal_query_security (GlEventView *view,
     GlEventViewPrivate *priv;
     GList *l;
     gsize n_results;
-    guint idle_id;
 
     priv = gl_event_view_get_instance_private (view);
     priv->results = gl_journal_query (priv->journal, query);
@@ -403,8 +409,9 @@ insert_journal_query_security (GlEventView *view,
         g_queue_push_tail (priv->pending_results, l->data);
     }
 
-    idle_id = g_idle_add ((GSourceFunc) insert_security_idle, view);
-    g_source_set_name_by_id (idle_id, G_STRFUNC);
+    priv->insert_idle_id = g_idle_add ((GSourceFunc) insert_security_idle,
+                                       view);
+    g_source_set_name_by_id (priv->insert_idle_id, G_STRFUNC);
 }
 
 static gboolean
@@ -441,6 +448,7 @@ insert_simple_idle (GlEventView *view)
                 priv->results_listbox = NULL;
                 priv->results = NULL;
 
+                priv->insert_idle_id = 0;
                 return G_SOURCE_REMOVE;
             }
         }
@@ -449,6 +457,7 @@ insert_simple_idle (GlEventView *view)
     }
     else
     {
+        priv->insert_idle_id = 0;
         return G_SOURCE_REMOVE;
     }
 }
@@ -461,7 +470,6 @@ insert_journal_query_simple (GlEventView *view,
     GlEventViewPrivate *priv;
     GList *l;
     gsize n_results;
-    guint idle_id;
 
     priv = gl_event_view_get_instance_private (view);
     priv->results = gl_journal_query (priv->journal, query);
@@ -480,8 +488,8 @@ insert_journal_query_simple (GlEventView *view,
         g_queue_push_tail (priv->pending_results, l->data);
     }
 
-    idle_id = g_idle_add ((GSourceFunc) insert_simple_idle, view);
-    g_source_set_name_by_id (idle_id, G_STRFUNC);
+    priv->insert_idle_id = g_idle_add ((GSourceFunc) insert_simple_idle, view);
+    g_source_set_name_by_id (priv->insert_idle_id, G_STRFUNC);
 }
 
 static gboolean
@@ -518,6 +526,7 @@ insert_cmdline_idle (GlEventView *view)
                 priv->results_listbox = NULL;
                 priv->results = NULL;
 
+                priv->insert_idle_id = 0;
                 return G_SOURCE_REMOVE;
             }
         }
@@ -526,6 +535,7 @@ insert_cmdline_idle (GlEventView *view)
     }
     else
     {
+        priv->insert_idle_id = 0;
         return G_SOURCE_REMOVE;
     }
 }
@@ -538,7 +548,6 @@ insert_journal_query_cmdline (GlEventView *view,
     GlEventViewPrivate *priv;
     GList *l;
     gsize n_results;
-    guint idle_id;
 
     priv = gl_event_view_get_instance_private (view);
     priv->results = gl_journal_query (priv->journal, query);
@@ -558,8 +567,9 @@ insert_journal_query_cmdline (GlEventView *view,
         g_queue_push_tail (priv->pending_results, l->data);
     }
 
-    idle_id = g_idle_add ((GSourceFunc) insert_cmdline_idle, view);
-    g_source_set_name_by_id (idle_id, G_STRFUNC);
+    priv->insert_idle_id = g_idle_add ((GSourceFunc) insert_cmdline_idle,
+                                       view);
+    g_source_set_name_by_id (priv->insert_idle_id, G_STRFUNC);
 }
 
 static void
@@ -909,6 +919,11 @@ gl_event_view_finalize (GObject *object)
     GlEventView *view = GL_EVENT_VIEW (object);
     GlEventViewPrivate *priv = gl_event_view_get_instance_private (view);
 
+    if (priv->insert_idle_id)
+    {
+        g_source_remove (priv->insert_idle_id);
+    }
+
     g_clear_pointer (&priv->search_text, g_free);
     g_clear_pointer (&priv->pending_results, g_queue_free);
 }
@@ -994,6 +1009,7 @@ gl_event_view_init (GlEventView *view)
     priv = gl_event_view_get_instance_private (view);
     priv->search_text = NULL;
     priv->active_listbox = NULL;
+    priv->insert_idle_id = 0;
     priv->journal = gl_journal_new ();
 
     /* TODO: Monitor and propagate any GSettings changes. */
